@@ -63,7 +63,7 @@ step_dummy_multi_choice <- function(recipe,
                                     keep_original_cols = FALSE,
                                     skip = FALSE,
                                     id = rand_id("dummy_multi_choice")) {
-  if (!is_tune(threshold) & !is_varying(threshold)) {
+  if (!is_tune(threshold)) {
     if (threshold < 0) {
       rlang::abort("`threshold` should be non-negative.")
     }
