@@ -49,7 +49,7 @@ step_holiday <-
            keep_original_cols = TRUE,
            skip = FALSE,
            id = rand_id("holiday")) {
-    if (!is_tune(holidays) & !is_varying(holidays)) {
+    if (!is_tune(holidays)) {
       all_days <- listHolidays()
       if (!all(holidays %in% all_days)) {
         rlang::abort("Invalid `holidays` value. See timeDate::listHolidays")
@@ -89,16 +89,7 @@ step_holiday_new <-
 #' @export
 prep.step_holiday <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-
-  holiday_data <- info[info$variable %in% col_names, ]
-  if (any(!holiday_data$type %in% c("date", "datetime"))) {
-    rlang::abort(
-      paste0(
-        "All variables for `step_holiday` should be either `Date` or",
-        "`POSIXct` classes."
-      )
-    )
-  }
+  check_type(training[, col_names], types = c("date", "datetime"))
 
   step_holiday_new(
     terms = x$terms,
