@@ -100,7 +100,7 @@ step_range_new <-
 #' @export
 prep.step_range <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-  check_type(training[, col_names])
+  check_type(training[, col_names], types = c("double", "integer"))
 
   mins <-
     vapply(training[, col_names], min, c(min = 0), na.rm = TRUE)
@@ -130,7 +130,7 @@ bake.step_range <- function(object, new_data, ...) {
     new_data[[column]] <- (new_data[[column]] - min) *
       (object$max - object$min) / (max - min) + object$min
 
-    if (object$clipping) {
+    if (!is.null(object$clipping) && object$clipping) {
       new_data[[column]] <- pmax(new_data[[column]], object$min)
       new_data[[column]] <- pmin(new_data[[column]], object$max)
     }
