@@ -191,6 +191,9 @@ recipe.formula <- function(formula, data, ...) {
     rlang::abort("`-` is not allowed in a recipe formula. Use `step_rm()` instead.")
   }
 
+  if (rlang::is_missing(data)) {
+    cli::cli_abort("Argument {.var data} is missing, with no default.")
+  }
   # Check for other in-line functions
   args <- form2args(formula, data, ...)
   obj <- recipe.data.frame(
@@ -390,7 +393,7 @@ prep.recipe <-
         inherits(x$var_info$type, "character")) {
       x$var_info <- x$var_info %>%
         dplyr::select(-type) %>%
-        dplyr::left_join(get_types(training), by = "variable") %>%
+        dplyr::left_join(get_types(training), by = "variable", multiple = "all") %>%
         dplyr::select(variable, type, role, source)
     }
 
@@ -398,7 +401,7 @@ prep.recipe <-
         inherits(x$term_info$type, "character")) {
       x$term_info <- x$term_info %>%
         dplyr::select(-type) %>%
-        dplyr::left_join(get_types(training), by = "variable") %>%
+        dplyr::left_join(get_types(training), by = "variable", multiple = "all") %>%
         dplyr::select(variable, type, role, source)
     }
 
@@ -431,12 +434,17 @@ prep.recipe <-
 
         # Compute anything needed for the preprocessing steps
         # then apply it to the current training set
-        x$steps[[i]] <-
+        x$steps[[i]] <- recipes_error_context(
           prep(x$steps[[i]],
             training = training,
             info = x$term_info
-          )
-        training <- bake(x$steps[[i]], new_data = training)
+          ),
+          step_name = class(x$steps[[i]])[[1L]]
+        )
+        training <- recipes_error_context(
+          bake(x$steps[[i]], new_data = training),
+          step_name = class(x$steps[[i]])[[1L]]
+        )
         if (!is_tibble(training)) {
           abort("bake() methods should always return tibbles")
         }
@@ -504,7 +512,7 @@ prep.recipe <-
       arrange(desc(number)) %>%
       summarise(
         type = list(dplyr::first(type)),
-        role = as.list(unique(unlist(role))),
+        role = list(unique(unlist(role))),
         source = dplyr::first(source),
         number = dplyr::first(number),
         skip = dplyr::first(skip),
@@ -696,43 +704,54 @@ bake.recipe <- function(object, new_data, ..., composition = "tibble") {
 #'
 #' @export
 print.recipe <- function(x, form_width = 30, ...) {
-  cat("Recipe\n\n")
-  cat("Inputs:\n\n")
-  no_role <- is.na(x$var_info$role)
-  if (any(!no_role)) {
-    tab <- as.data.frame(table(x$var_info$role))
-    colnames(tab) <- c("role", "#variables")
-    print(tab, row.names = FALSE)
-    if (any(no_role)) {
-      cat("\n ", sum(no_role), "variables with undeclared roles\n")
-    }
-  } else {
-    cat(" ", nrow(x$var_info), "variables (no declared roles)\n")
-  }
+  cli::cli_div(theme = list(.pkg = list("vec-trunc" = Inf, "vec-last" = ", ")))
+
+  cli::cli_h1("Recipe")
+  cli::cli_h3("Inputs")
+
+  tab <- table(x$var_info$role, useNA = "ifany")
+  tab <- stats::setNames(tab, names(tab))
+  names(tab)[is.na(names(tab))] <- "undeclared role"
+
+  roles <- c("outcome", "predictor", "case_weights", "undeclared role")
+
+  tab <- c(
+    tab[names(tab) == roles[1]],
+    tab[names(tab) == roles[2]],
+    tab[names(tab) == roles[3]],
+    sort(tab[!names(tab) %in% roles], TRUE),
+    tab[names(tab) == roles[4]]
+  )
+
+  cli::cli_text("Number of variables by role")
+
+  spaces_needed <- max(nchar(names(tab))) - nchar(names(tab)) +
+    max(nchar(tab)) - nchar(tab)
+
+  cli::cli_verbatim(
+    glue::glue("{names(tab)}: {strrep('\ua0', spaces_needed)}{tab}")
+  )
+
   if ("tr_info" %in% names(x)) {
+    cli::cli_h3("Training information")
     nmiss <- x$tr_info$nrows - x$tr_info$ncomplete
-    cat("\nTraining data contained ",
-      x$tr_info$nrows,
-      " data points and ",
-      sep = ""
+    nrows <- x$tr_info$nrows
+
+    cli::cli_text(
+      "Training data contained {nrows} data points and {cli::no(nmiss)} \\
+       incomplete row{?s}."
     )
-    if (x$tr_info$nrows == x$tr_info$ncomplete) {
-      cat("no missing data.\n")
-    } else {
-      cat(
-        nmiss,
-        "incomplete",
-        ifelse(nmiss > 1, "rows.", "row."),
-        "\n"
-      )
-    }
   }
+
   if (!is.null(x$steps)) {
-    cat("\nOperations:\n\n")
-    for (i in seq_along(x$steps)) {
-      print(x$steps[[i]], form_width = form_width)
-    }
+    cli::cli_h3("Operations")
   }
+
+    for (step in x$steps) {
+    print(step, form_width = form_width)
+  }
+  cli::cli_end()
+
   invisible(x)
 }
 
@@ -770,7 +789,12 @@ print.recipe <- function(x, form_width = 30, ...) {
 summary.recipe <- function(object, original = FALSE, ...) {
   if (original) {
     res <- object$var_info
-    res <- dplyr::left_join(res, bake_req_tibble(object), by = "role")
+    res <- dplyr::left_join(
+      res,
+      bake_req_tibble(object),
+      by = "role",
+      multiple = "all"
+    )
   } else {
     res <- object$term_info
   }
@@ -789,23 +813,28 @@ bake_req_tibble <- function(x) {
 
 #' Extract transformed training set
 #'
+#' @description
+#' `r lifecycle::badge('superseded')`
+#'
 #' As of `recipes` version 0.1.14, **`juice()` is superseded** in favor of
 #' `bake(object, new_data = NULL)`.
 #'
-#' As steps are estimated by `prep`, these operations are
-#'  applied to the training set. Rather than running [bake()]
-#'  to duplicate this processing, this function will return
-#'  variables from the processed training set.
+#' As steps are estimated by `prep`, these operations are applied to the
+#' training set. Rather than running [bake()] to duplicate this processing, this
+#' function will return variables from the processed training set.
+#'
 #' @inheritParams bake.recipe
-#' @param object A `recipe` object that has been prepared
-#'   with the option `retain = TRUE`.
-#' @details When preparing a recipe, if the training data set is
-#'  retained using `retain = TRUE`, there is no need to [bake()] the
-#'  recipe to get the preprocessed training set.
+#' @param object A `recipe` object that has been prepared with the option
+#'   `retain = TRUE`.
+#'
+#' @details
+#' `juice()` will return the results of a recipe where _all steps_ have been
+#' applied to the data, irrespective of the value of the step's `skip` argument.
+#'
+#' `juice()` can only be used if a recipe was prepped with `retain = TRUE`. This
+#' is equivalent to `bake(object, new_data = NULL)` which is the preferred way
+#' to extract the transformation of the training data set.
 #'
-#'  `juice()` will return the results of a recipe where _all steps_
-#'  have been applied to the data, irrespective of the value of
-#'  the step's `skip` argument.
 #' @export
 #' @seealso [recipe()] [prep()] [bake()]
 juice <- function(object, ..., composition = "tibble") {
