@@ -56,7 +56,7 @@ step_regex <- function(recipe,
                        input = NULL,
                        skip = FALSE,
                        id = rand_id("regex")) {
-  if (!is_tune(pattern) & !is_varying(pattern)) {
+  if (!is_tune(pattern)) {
     if (!is.character(pattern)) {
       rlang::abort("`pattern` should be a character string")
     }
@@ -112,7 +112,7 @@ step_regex_new <-
 #' @export
 prep.step_regex <- function(x, training, info = NULL, ...) {
   col_name <- recipes_eval_select(x$terms, training, info)
-  check_type(training[, col_name], quant = FALSE)
+  check_type(training[, col_name], types = c("string", "factor", "ordered"))
 
   if (length(col_name) > 1) {
     rlang::abort("The selector should select at most a single variable")
@@ -152,7 +152,7 @@ bake.step_regex <- function(object, new_data, ...) {
     )
   )
   if (length(object$options) > 0) {
-    regex <- mod_call_args(regex, args = object$options)
+    regex <- rlang::call_modify(regex, !!!object$options)
   }
 
   new_data[, object$result] <- ifelse(eval(regex), 1L, 0L)
