@@ -83,7 +83,7 @@ step_string2factor <-
            ordered = FALSE,
            skip = FALSE,
            id = rand_id("string2factor")) {
-    if (!is_tune(ordered) & !is_varying(ordered)) {
+    if (!is_tune(ordered)) {
       if (!is.logical(ordered) || length(ordered) != 1) {
         rlang::abort("`ordered` should be a single logical variable")
       }
@@ -127,20 +127,7 @@ get_ord_lvls <- function(x) {
 #' @export
 prep.step_string2factor <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-  str_check <-
-    vapply(
-      training[, col_names],
-      function(x) is.character(x) | is.factor(x),
-      logical(1)
-    )
-  if (any(!str_check)) {
-    rlang::abort(
-      paste0(
-        "The following variables are not character vectors: ",
-        paste0("`", names(str_check)[!str_check], "`", collapse = ", ")
-      )
-    )
-  }
+  check_type(training[, col_names], types = c("string", "factor", "ordered"))
 
   if (is.null(x$levels)) {
     res <- lapply(training[, col_names], get_ord_lvls)
