@@ -120,7 +120,7 @@ step_window <-
     }
 
     ## ensure size is odd, integer, and not too small
-    if (!is_tune(size) & !is_varying(size)) {
+    if (!is_tune(size)) {
       if (is.na(size) | is.null(size)) {
         rlang::abort("`size` needs a value.")
       }
@@ -187,7 +187,7 @@ step_window_new <-
 #' @export
 prep.step_window <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-  check_type(training[, col_names])
+  check_type(training[, col_names], types = c("double", "integer"))
 
   if (!is.null(x$names)) {
     if (length(x$names) != length(col_names)) {
